abacusai.monitor_alert_version — AbacusAI documentation

# `abacusai.monitor_alert_version`

## Module Contents

### Classes

`MonitorAlertVersion` | A monitor alert version

class abacusai.monitor_alert_version.MonitorAlertVersion(client, name=None, monitorAlertVersion=None, monitorAlertId=None, status=None, createdAt=None, alertingStartedAt=None, alertingCompletedAt=None, error=None, modelMonitorVersion=None, conditionConfig=None, actionConfig=None, alertResult=None, actionStatus=None, actionError=None, actionStartedAt=None, actionCompletedAt=None, conditionDescription=None, actionDescription=None, alertType=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A monitor alert version

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The user-friendly name for the monitor alert.

    - monitorAlertVersion (str) – The identifier for the alert version.

    - monitorAlertId (str) – The identifier for the alert.

    - status (str) – The current status of the monitor alert.

    - createdAt (str) – Date and time at which the monitor alert was created.

    - alertingStartedAt (str) – The start time and date of the monitor alerting process.

    - alertingCompletedAt (str) – The end time and date of the monitor alerting process.

    - error (str) – Relevant error if the status is FAILED.

    - modelMonitorVersion (str) – The model monitor version associated with the monitor alert version.

    - conditionConfig (dict) – The condition configuration for this alert.

    - actionConfig (dict) – The action configuration for this alert.

    - alertResult (str) – The current result of the alert

    - actionStatus (str) – The current status of the action as a result of the monitor alert.

    - actionError (str) – Relevant error if the action status is FAILED.

    - actionStartedAt (str) – The start time and date of the actionfor the alerting process.

    - actionCompletedAt (str) – The end time and date of the actionfor the alerting process.

    - conditionDescription (str) – User friendly description of the condition

    - actionDescription (str) – User friendly description of the action

    - alertType (str) – The type of the alert

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      MonitorAlertVersion

  describe()

    Describes a given monitor alert version id

    Parameters:

      monitor_alert_version (str) – Unique string identifier for the monitor alert.

    Returns:

      An object describing the monitor alert version.

    Return type:

      MonitorAlertVersion

  wait_for_monitor_alert(timeout=1200)

    A waiting call until model monitor version is ready.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the monitor alert version.

    Returns:

      A string describing the status of a monitor alert version (pending, running, complete, etc.).

    Return type:

      str